/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Copyright (C) 2012 Chris Mrwald (chris at pl2 dot com)
 * All Rights Reserved.
 * Contributed to and published at the Hunspell project
 * http://hunspell.sourceforge.net.
 *
 * Contributor(s):
 * 
 *  
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** **/

/* History
 * 2012-07-24 Chris Mrwald - created
 *
 */

#include "stdafx.h"
#include <richedit.h>
#include "resource.h"

#include "SpellChecker.h"
#include "stringW32.h"

HWND  myRichEditHWND = NULL;

INT_PTR CALLBACK dlgProc (HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
  switch(uMsg) {
    case WM_INITDIALOG:
      myRichEditHWND = GetDlgItem (hwndDlg, IDC_RICHEDIT2);
      // set some text length limit
      SendMessage (myRichEditHWND, EM_LIMITTEXT, (WPARAM)MAX_STRING_LEN - 1, 0);
      // we need key and mouse events, see WM_NOTIFY
      SendMessage (myRichEditHWND, EM_SETEVENTMASK, 0, ENM_KEYEVENTS | ENM_MOUSEEVENTS);
      // misc options
      SendMessage (myRichEditHWND, EM_SETOPTIONS, ECOOP_OR, ECO_AUTOWORDSELECTION | ECO_SELECTIONBAR);
      SendMessage (myRichEditHWND, EM_SETZOOM, 64, 52);
      return TRUE;
    case WM_COMMAND:
		  switch (LOWORD (wParam)) {
		    case IDOK:
        case IDCANCEL:
          PostQuitMessage(0);
          EndDialog(hwndDlg, 0);
          return TRUE;
		  }
      break;
	  case WM_NOTIFY:
    {
      MSGFILTER*  msgf = (MSGFILTER*)lParam;
      if (msgf && msgf->nmhdr.hwndFrom == myRichEditHWND)
        spellchecker_process (myRichEditHWND, msgf);
      return FALSE;
    }
    default:
      break;
  }
  return FALSE;
}


int APIENTRY _tWinMain(HINSTANCE hInstance,
                     HINSTANCE hPrevInstance,
                     LPTSTR    lpCmdLine,
                     int       nCmdShow)
{
	UNREFERENCED_PARAMETER(hPrevInstance);
	UNREFERENCED_PARAMETER(lpCmdLine);

  HINSTANCE module;
	MSG       msg;
  HWND      hWnd;

	module  = LoadLibrary(L"riched20.dll");  // RichEdit 3.0
  hWnd    = CreateDialog (hInstance, MAKEINTRESOURCE (IDD_DIALOG1),
              GetDesktopWindow(), dlgProc);

  if (hWnd && myRichEditHWND) {
    // load a dictionary
    if (!spellchecker_dictname_set ("en_US"))
      SetWindowText (myRichEditHWND, L"\r\nDictionary not found.\r\n");
    ShowWindow (hWnd, SW_SHOW);
    UpdateWindow(hWnd);
  } else {
    if (module)
      FreeLibrary(module);
    return -1;
  }

	while (GetMessage(&msg, NULL, 0, 0)) {
    TranslateMessage(&msg);
    DispatchMessage(&msg);
	}

  spellchecker_term();

  if (module)
    FreeLibrary(module);
	return (int)msg.wParam;
}


